import { OnInit, EventEmitter } from '@angular/core';
/**
 * These pagination controls are designed to work with a pagination list wrapper, which is taken as an input along with
 * the desired page size.
 *
 * @input settings: this is the pagination wrapper.
 * @input pageSize: this is the desired number of results per page.
 *
 * @output emitPaginate: this event is intended to be heard by a handler which queries the wrapper for the desired
 * range of results.
 *
 * ### Simple Example
 *
 * ```
 * <pagination [settings]="paginationSettings" (emitPaginate)="onPaginate($event)"></pagination>
 * ```
 *
 */
export declare class DatePicker implements OnInit {
    month: number;
    year: number;
    monthSpan: number;
    maxRange: number;
    beginRange: number | string;
    endRange: number | string;
    beginDate: number | string;
    endDate: number | string;
    alignCal: string;
    emitDate: EventEmitter<{}>;
    monthText: string[];
    dayText: string[];
    private hideComponent;
    private paginationLeft;
    private paginationRight;
    private alignClass;
    private _year;
    private _monthSpan;
    private _maxRange;
    private _beginRange;
    private _endRange;
    private _beginDate;
    private _endDate;
    private _baseMonth;
    private now;
    viewModel: Object[];
    ngOnInit(): void;
    show(): void;
    close(): void;
    /**
     * Method called by template to submit date selection
     * Emits event through the output (only function to do so)
     */
    emit(): void;
    /**
     * Method called by template to display new set of months in the viewModel
     * Calls updateViewModel without mutating selected dates
     */
    nextMonth(interval?: number): void;
    /**
     * Method to register date selection called by the template. Updates viewModel.
     * @param {number} year - Chosen year
     * @param {number} month - Chosen month
     * @param {number} day - Chosen day
     */
    chooseDate(year: number, month: number, day: number): void;
    /**
     * Internal method to trigger an update of the calendar with latest data
     * Side-effect: this.viewModel gets updated with new calendar data
     * @param {number} [newMonth=currentMonth] New base month
     */
    protected updateViewModel(newMonth?: number): void;
    /**
     * Method that generates calendar HTML
     * @param {number} year Calendar display year.
     * @param {number} month Calendar display month. (zero-based)
     * @return {string[][]}
     */
    protected generateCalendar(year: number, month: number): string[][];
    /**
     * Utility method to sanity-check given dates
     * SIDE-EFFECT: Will mutate properties _beginDate and/or _endDate to appropriate
     *   values if they are found to be insane and sanitize flag is on.
     * @param {boolean} [sanitize=true] Fix invalid values (induces side-effect)
     * @return {boolean} Go for launch?
     */
    protected sanityCheck(sanitize?: boolean): boolean;
}
