"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
var core_1 = require('@angular/core');
var _ = require('lodash');
/**
 * A component which renders indicators when there is hidden content which can be scrolled to bring into view.  It wraps
 * your contents and adds arrows which display when the user has scrolled more than 10 pixels from the top or bottom of
 * the contents.
 *
 * IMPORTANT: If you need a buffer between the element upon which you attach the directive and the content (eg: for the
 * table headers in a <table>):
 *
 *      1) Attach the local var `#scrollableComponent` to the <scrollable-container> tag as shown below.
 *
 *      2) Attach the local var `#scrollableContent` to the scrollable content's container.
 *
 *      3) Add a `scroll` event handler which calls `scrollableComponent.onScroll()` to the same element with
 *          `#scrollableContent`.
 *
 *      4) Add the `#scrollableTop` local var to the element directly above your scrollable content in the DOM tree,
 *          which will act as a buffer between the top of the `scrollable-container` tag and the scrollable content.
 *
 * See demo implementation for styles.
 *
 * ### Simple Example
 *
 * Using table, buffer needed for table headers:
 * ```
 *  <scrollable-container #scrollableComponent>
 *      <table>
 *          <thead #scrollableTop>
 *              <tr>...</tr>
 *              <tr>...</tr>
 *              <tr>...</tr>
 *          </thead>
 *          <tbody #scrollableContent (scroll)="scrollableComponent.onScroll()">
 *              <td>...</td>
 *              <td>...</td>
 *          </tbody>
 *      </table>
 *  </scrollable-container>
 * ```
 *
 * Using divs, no buffer needed for table headers:
 * ```
 *  <scrollable-container>
 *      <div>
 *          my content
 *      </div>
 *      <div>
 *          my content
 *      </div>
 *      <div>
 *          my content
 *      </div>
 *      <div>
 *          my content
 *      </div>
 *      <div>
 *          my content
 *      </div>
 *      <div>
 *          my content
 *      </div>
 *  </scrollable-container>
 * ```
 */
var HintScroll = (function () {
    function HintScroll(el) {
        this.el = el;
        this.checkedVisibility = new core_1.EventEmitter();
        this.onScroll = _.debounce(this.verifyVisibility, 500);
    }
    Object.defineProperty(HintScroll.prototype, "newContentLoaded", {
        set: function (newContentLoaded) {
            if (newContentLoaded) {
                this.verifyVisibility();
                this.checkedVisibility.emit('success');
            }
        },
        enumerable: true,
        configurable: true
    });
    HintScroll.prototype.ngAfterViewInit = function () {
        var _this = this;
        setTimeout(function () {
            if (_this.targetContainer) {
                _this.scrollableEl = _this.targetContainer.nativeElement;
                _this.fromTop = _this.top.nativeElement.clientHeight - 1 + 'px';
            }
            else {
                _this.fromTop = '0px';
            }
            _this.verifyVisibility();
        });
    };
    HintScroll.prototype.showTop = function () {
        var firstElementTop;
        var bodyTop;
        var children;
        if (this.targetContainer) {
            if (!this.scrollableEl || !this.scrollableEl.children.length) {
                return false;
            }
            children = this.scrollableEl.children;
            firstElementTop = children[0].getBoundingClientRect().top;
            bodyTop = this.scrollableEl.getBoundingClientRect().top;
        }
        else {
            if (!this.el.nativeElement ||
                !this.el.nativeElement.getElementsByClassName('content-wrapper')[0] ||
                !this.el.nativeElement.getElementsByClassName('content-wrapper')[0].children.length) {
                return false;
            }
            children = this.el.nativeElement.getElementsByClassName('content-wrapper')[0].children;
            firstElementTop = children[0].getBoundingClientRect().top;
            bodyTop = this.el.nativeElement.getBoundingClientRect().top;
        }
        return firstElementTop < (bodyTop - 10);
    };
    HintScroll.prototype.showBottom = function () {
        var lastElementBottom;
        var bodyBottom;
        var children;
        if (this.targetContainer) {
            if (!this.scrollableEl || !this.scrollableEl.children.length) {
                return false;
            }
            children = this.scrollableEl.children;
            lastElementBottom = children[children.length - 1].getBoundingClientRect().bottom;
            bodyBottom = this.scrollableEl.getBoundingClientRect().bottom;
        }
        else {
            if (!this.el.nativeElement ||
                !this.el.nativeElement.getElementsByClassName('content-wrapper')[0] ||
                !this.el.nativeElement.getElementsByClassName('content-wrapper')[0].children.length) {
                return false;
            }
            children = this.el.nativeElement.getElementsByClassName('content-wrapper')[0].children;
            lastElementBottom = children[children.length - 1].getBoundingClientRect().bottom;
            bodyBottom = this.el.nativeElement.getBoundingClientRect().bottom;
        }
        return lastElementBottom > (bodyBottom + 10);
    };
    HintScroll.prototype.verifyVisibility = function () {
        this.showBottom();
        this.showTop();
    };
    __decorate([
        core_1.ContentChild('scrollableContent'), 
        __metadata('design:type', core_1.ElementRef)
    ], HintScroll.prototype, "targetContainer", void 0);
    __decorate([
        core_1.ContentChild('scrollableTop'), 
        __metadata('design:type', core_1.ElementRef)
    ], HintScroll.prototype, "top", void 0);
    __decorate([
        core_1.Output(), 
        __metadata('design:type', Object)
    ], HintScroll.prototype, "checkedVisibility", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Boolean), 
        __metadata('design:paramtypes', [Boolean])
    ], HintScroll.prototype, "newContentLoaded", null);
    HintScroll = __decorate([
        core_1.Component({
            selector: 'scrollable-container',
            styles: ["\n        :host { position: relative; display: block; }\n        .hint-scroll {\n            width: 100%;\n            height: 20px;\n            background-color: rgba(226, 226, 226, 0.70);\n            position: absolute;\n            display: flex;\n            z-index: 2;\n            cursor: default;\n        }\n        .arrow {\n            margin: auto;\n            color: white;\n            transform: rotate(90deg) scale(3);\n        }\n        .bottom { bottom: 0; }\n        .bottom-fix { bottom: -1px; }\n        .content-wrapper {\n            max-height: inherit;\n            height: inherit;\n            overflow: auto;\n        }\n    "],
            template: "\n    <div class=\"hint-scroll\" *ngIf=\"showTop()\" [ngStyle]=\"{'top': fromTop}\"><div class=\"arrow\">&lsaquo;</div></div>\n    <div [ngClass]=\"{ 'content-wrapper': !targetContainer }\" (scroll)=\"onScroll()\">\n        <ng-content></ng-content>\n    </div>\n    <div class=\"hint-scroll bottom\" [ngClass]=\"{ 'bottom-fix': !targetContainer }\" *ngIf=\"showBottom()\">\n        <div class=\"arrow\">&rsaquo;</div>\n    </div>\n    "
        }),
        __param(0, core_1.Inject(core_1.ElementRef)), 
        __metadata('design:paramtypes', [core_1.ElementRef])
    ], HintScroll);
    return HintScroll;
}());
exports.HintScroll = HintScroll;
//# sourceMappingURL=hint-scroll.js.map