import { EventEmitter, OnInit } from '@angular/core';
/**
 * A component which can be used as a header to a table which allows for emitting events to allow for
 * sorting elements by attributes.
 *
 * ### Simple Example
 *
 * ```
 * <list-headers (emitSort)="sort($event)" [headers]="headers"></list-headers>
 *
 * ```
 *
 * In model:
 * ```
 *  class Component {
 *      public headers = [
 *          { label: 'display name',    property: 'displayName',    styles: { width: '23%' }},
 *          { label: 'description',     property: 'description',    styles: { width: '54%' }, sortOnInit: 'desc'},
 *          { label: 'modified',        property: 'lastModifiedAt', styles: { width: '23%' }}
 *      ];
 *  }
 * ```
 *
 * This will trigger sort() upon clicking on one of the header values to be sorted.
 *
 * Header values are also set as headers using the interface defined in its own namespace.  Note that the default
 * sorting criteria can be set by adding the optional `sortOnInit` property to the desired header.
 */
export declare class ListHeaders implements OnInit {
    headers: ListHeaders.IHeader[];
    emitSort: EventEmitter<{}>;
    private sortedBy;
    private ascOrder;
    sort(header: any): void;
    ngOnInit(): void;
}
export declare namespace ListHeaders {
    interface IStyle {
        width: string;
    }
    interface IHeader {
        label: string;
        property: string;
        styles: IStyle;
        sortOnInit?: ascOrder;
    }
    type ascOrder = 'asc' | 'desc';
}
