"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var core_1 = require('@angular/core');
var _ = require('lodash');
var styles = require('!!css-loader!less-loader!./list-headers.less');
/**
 * A component which can be used as a header to a table which allows for emitting events to allow for
 * sorting elements by attributes.
 *
 * ### Simple Example
 *
 * ```
 * <list-headers (emitSort)="sort($event)" [headers]="headers"></list-headers>
 *
 * ```
 *
 * In model:
 * ```
 *  class Component {
 *      public headers = [
 *          { label: 'display name',    property: 'displayName',    styles: { width: '23%' }},
 *          { label: 'description',     property: 'description',    styles: { width: '54%' }, sortOnInit: 'desc'},
 *          { label: 'modified',        property: 'lastModifiedAt', styles: { width: '23%' }}
 *      ];
 *  }
 * ```
 *
 * This will trigger sort() upon clicking on one of the header values to be sorted.
 *
 * Header values are also set as headers using the interface defined in its own namespace.  Note that the default
 * sorting criteria can be set by adding the optional `sortOnInit` property to the desired header.
 */
var ListHeaders = (function () {
    function ListHeaders() {
        this.emitSort = new core_1.EventEmitter();
    }
    ListHeaders.prototype.sort = function (header) {
        if (!header) {
            return;
        }
        if (this.sortedBy === header) {
            this.ascOrder = !this.ascOrder;
        }
        else {
            this.ascOrder = true;
        }
        this.sortedBy = header;
        this.emitSort.emit({
            order: this.ascOrder ? 'asc' : 'desc',
            sortBy: this.sortedBy
        });
    };
    ListHeaders.prototype.ngOnInit = function () {
        var sortHeader = _.find(this.headers, function (header) {
            return header.sortOnInit;
        }) || this.headers[0];
        this.ascOrder = sortHeader.sortOnInit ? sortHeader.sortOnInit === 'asc' : true;
        this.sortedBy = sortHeader.property;
    };
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Array)
    ], ListHeaders.prototype, "headers", void 0);
    __decorate([
        core_1.Output(), 
        __metadata('design:type', Object)
    ], ListHeaders.prototype, "emitSort", void 0);
    ListHeaders = __decorate([
        core_1.Component({
            selector: 'list-headers',
            styles: [styles.toString()],
            template: "\n        <div *ngFor=\"let header of headers\" (click)=\"sort(header.property)\" [ngStyle]=\"header.styles\">\n            <span class=\"header-title\">{{(header.label || header.property) | uppercase}} </span>\n            <span class=\"header-icon\"\n                  [ngClass]=\"ascOrder ? 'arrow-down' : 'arrow-up'\"\n                  *ngIf=\"header.property && sortedBy === header.property\">\n            </span>\n        </div>\n    "
        }), 
        __metadata('design:paramtypes', [])
    ], ListHeaders);
    return ListHeaders;
}());
exports.ListHeaders = ListHeaders;
var ListHeaders;
(function (ListHeaders) {
    'use strict';
})(ListHeaders = exports.ListHeaders || (exports.ListHeaders = {}));
//# sourceMappingURL=list-headers.js.map