"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var core_1 = require('@angular/core');
var tooltip_service_1 = require('../../directives/tooltip/tooltip-service');
var helpers = require('./position-helpers');
var positionKeys = {
    left: {
        edge: 'left',
        offsetEdge: 'offsetLeft',
        offsetSize: 'offsetWidth',
        size_: 'width'
    },
    top: {
        edge: 'top',
        offsetEdge: 'offsetTop',
        offsetSize: 'offsetHeight',
        size_: 'height'
    }
};
var styles = require('!!css-loader!less-loader!./tooltip.less').toString();
var Tooltip = (function () {
    function Tooltip(service, renderer) {
        this.service = service;
        this.renderer = renderer;
        this.options = {};
        this.showTooltip = false;
        this.disabled = false;
    }
    Tooltip.prototype.ngAfterViewInit = function () {
        var _this = this;
        this.service.tooltipOptions.subscribe(function (options) {
            _this.setOptions(options);
            if (!_this.options.target || !_this.options.hovering) {
                return;
            }
            requestAnimationFrame(function () { return _this.positionTooltip(); });
        });
    };
    Tooltip.prototype.setOptions = function (options) {
        if (!options) {
            return;
        }
        this.options = options;
        this.showTooltip = options.enabled && options.hovering;
        this.disabled = !options.enabled;
        this.renderer.setElementStyle(this.tooltipContainer.nativeElement, 'maxWidth', options.maxWidth + 'px');
    };
    Tooltip.prototype.positionTooltip = function () {
        var target = this.options.target;
        var tooltip = this.tooltipContainer.nativeElement;
        var newPositions = this.calculatePositions(target, tooltip, this.options.placement);
        this.setNewPosition(tooltip, newPositions);
    };
    Tooltip.prototype.setNewPosition = function (tooltip, positions) {
        this.renderer.setElementStyle(tooltip, 'top', positions.top + 'px');
        this.renderer.setElementStyle(tooltip, 'left', positions.left + 'px');
    };
    Tooltip.prototype.calculatePositions = function (target, tooltip, placement) {
        var positions = {};
        var verticalPlacement = placement === 'top' || placement === 'bottom';
        if (verticalPlacement) {
            positions.top = this.edgePosition(target, tooltip, placement, 'top');
            positions.left = this.centeredPosition(target, tooltip, 'left');
        }
        else {
            positions.top = this.centeredPosition(target, tooltip, 'top');
            positions.left = this.edgePosition(target, tooltip, placement, 'left');
        }
        return positions;
    };
    Tooltip.prototype.edgePosition = function (target, tooltip, placement, styleProp) {
        var edgeKey = positionKeys[styleProp].edge;
        var offsetEdgeKey = positionKeys[styleProp].offsetEdge;
        var offsetSizeKey = positionKeys[styleProp].offsetSize;
        var tooltipRect = tooltip.getBoundingClientRect();
        var targetEdge = target.getBoundingClientRect()[edgeKey];
        var tooltipEdge = tooltipRect[edgeKey];
        var tooltipOffsetSize = tooltip[offsetSizeKey];
        var tooltipOffsetEdge = tooltip[offsetEdgeKey];
        var targetSize = target[offsetSizeKey];
        var isNearSideTooltip = placement === 'left' || placement === 'top';
        return helpers.calculateEdgeOffsetPosition({
            contentEdge: tooltipEdge,
            contentOffsetEdge: tooltipOffsetEdge,
            contentOffsetSize: tooltipOffsetSize,
            positionNearSide: isNearSideTooltip,
            targetEdge: targetEdge,
            targetSize: targetSize
        });
    };
    Tooltip.prototype.centeredPosition = function (target, tooltip, styleProp) {
        var offsetSizeKey = positionKeys[styleProp].offsetSize;
        var offsetEdgeKey = positionKeys[styleProp].offsetEdge;
        var edgeKey = positionKeys[styleProp].edge;
        var tooltipRect = tooltip.getBoundingClientRect();
        var targetRect = target.getBoundingClientRect();
        var tooltipOffsetEdge = tooltip[offsetEdgeKey];
        var tooltipOffsetSize = tooltip[offsetSizeKey];
        var tooltipEdge = tooltipRect[edgeKey];
        var targetOffsetSize = target[offsetSizeKey];
        var targetEdge = targetRect[edgeKey];
        return helpers.calculateCenteredOffsetPosition({
            contentEdge: tooltipEdge,
            contentOffsetEdge: tooltipOffsetEdge,
            contentOffsetSize: tooltipOffsetSize,
            targetEdge: targetEdge,
            targetSize: targetOffsetSize
        });
    };
    __decorate([
        core_1.ViewChild('tooltipContainer'), 
        __metadata('design:type', core_1.ElementRef)
    ], Tooltip.prototype, "tooltipContainer", void 0);
    Tooltip = __decorate([
        core_1.Component({
            selector: 'ue-tooltip',
            styles: [styles],
            template: "\n        <div #tooltipContainer class=\"ue-tooltip-container\" [ngClass]=\"{'ue-tooltip-show': showTooltip, 'ue-tooltip-disabled': disabled}\">\n            <div class=\"ue-tooltip-pointer ue-tooltip-pointer-{{ options.placement }}\"></div>\n            <div class=\"ue-tooltip-content ue-tooltip-content-{{ options.placement }}\">{{ options.content }}</div>\n        </div>\n    "
        }), 
        __metadata('design:paramtypes', [tooltip_service_1.TooltipService, core_1.Renderer])
    ], Tooltip);
    return Tooltip;
}());
exports.Tooltip = Tooltip;
//# sourceMappingURL=tooltip.js.map