"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var core_1 = require('@angular/core');
var Subject_1 = require('rxjs/Subject');
var styles = require('!!css-loader!less-loader!./value-handler.less');
var ValueHandler = (function () {
    function ValueHandler() {
        var _this = this;
        this.required = true;
        this.enableTooltip = true;
        this.invalidMessage = 'This value is required';
        this.inputValueStream = new Subject_1.Subject();
        this.editing = false;
        this.saving = false;
        this.success = false;
        this.error = false;
        this.invalid = false;
        this.tooltipPlace = 'top';
        this.emitChange = new core_1.EventEmitter();
        this.save = function (value) {
            if (_this.invalid) {
                return;
            }
            if (_this.required && !value) {
                _this.invalid = true;
                setTimeout(function () {
                    _this.invalid = false;
                }, 1500);
                return;
            }
            value = value.trim();
            if (value === _this.value) {
                _this.editing = false;
                return;
            }
            _this.value = value;
            _this.saving = true;
            var observer = new Subject_1.Subject();
            var subscription = observer.subscribe(function () {
                _this.onSuccess();
                subscription.unsubscribe();
            }, function () {
                _this.onError();
                subscription.unsubscribe();
            });
            _this.emitChange.emit({ property: _this.property, subject: observer, value: value });
        };
    }
    Object.defineProperty(ValueHandler.prototype, "optional", {
        set: function (value) {
            if (value) {
                this.required = false;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ValueHandler.prototype, "original", {
        set: function (value) {
            this._original = value;
            if (!this.editing) {
                this.value = value;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ValueHandler.prototype, "validation", {
        set: function (validationRule) {
            this._validateFn = validationRule.fn;
            this.invalidMessage = validationRule.message;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ValueHandler.prototype, "place", {
        set: function (place) {
            if (!place) {
                return;
            }
            this.tooltipPlace = place;
        },
        enumerable: true,
        configurable: true
    });
    ValueHandler.prototype.validate = function (value) {
        this.inputValueStream.next(value);
    };
    ValueHandler.prototype.startEditing = function () {
        this.editing = true;
    };
    ValueHandler.prototype.onError = function () {
        var _this = this;
        this.saving = false;
        this.error = true;
        this.input.nativeElement.focus();
        setTimeout(function () {
            _this.error = false;
            _this.input.nativeElement.focus();
        }, 200);
    };
    ValueHandler.prototype.onSuccess = function () {
        var _this = this;
        this.saving = false;
        this.success = true;
        this.editing = false;
        setTimeout(function () {
            _this.success = false;
            _this.verifyTooltipVisibility();
        }, 200);
    };
    ValueHandler.prototype.onTab = function (value, event) {
        event.preventDefault();
        this.save(value);
    };
    ValueHandler.prototype.cancel = function () {
        this.invalid = false;
        if (!this.saving) {
            this.value = this._original;
            this.editing = false;
        }
    };
    ValueHandler.prototype.verifyTooltipVisibility = function () {
        if (!this.span) {
            return;
        }
        if (this.span.nativeElement.offsetWidth && this.span.nativeElement.scrollWidth) {
            this.enableTooltip = this.span.nativeElement.offsetWidth <= this.span.nativeElement.scrollWidth;
        }
        else {
            this.enableTooltip = true;
        }
    };
    ValueHandler.prototype.ngAfterViewInit = function () {
        var _this = this;
        setTimeout(function () {
            _this.verifyTooltipVisibility();
        });
        this.inputValueStream
            .debounceTime(300)
            .distinctUntilChanged()
            .subscribe(function (term) {
            if (_this._validateFn) {
                _this.invalid = _this.error = !_this._validateFn(term);
            }
        });
    };
    __decorate([
        core_1.Input(), 
        __metadata('design:type', String)
    ], ValueHandler.prototype, "value", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', String)
    ], ValueHandler.prototype, "property", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Boolean), 
        __metadata('design:paramtypes', [Boolean])
    ], ValueHandler.prototype, "optional", null);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', String), 
        __metadata('design:paramtypes', [String])
    ], ValueHandler.prototype, "original", null);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Object), 
        __metadata('design:paramtypes', [Object])
    ], ValueHandler.prototype, "validation", null);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', String), 
        __metadata('design:paramtypes', [String])
    ], ValueHandler.prototype, "place", null);
    __decorate([
        core_1.Output(), 
        __metadata('design:type', Object)
    ], ValueHandler.prototype, "emitChange", void 0);
    __decorate([
        core_1.ViewChild('propertyInput'), 
        __metadata('design:type', core_1.ElementRef)
    ], ValueHandler.prototype, "input", void 0);
    __decorate([
        core_1.ViewChild('propertySpan'), 
        __metadata('design:type', core_1.ElementRef)
    ], ValueHandler.prototype, "span", void 0);
    ValueHandler = __decorate([
        core_1.Component({
            selector: 'value-handler',
            styles: [styles.toString()],
            template: "\n        <span class=\"property\" [ueTooltip]=\"value\" (click)=\"startEditing()\" ueTooltipPlacement=\"{{tooltipPlace}}\"\n            #propertySpan [ueTooltipEnabled]=\"enableTooltip\"\n            *ngIf=\"!editing\" [ngClass]=\"{ 'success': success, 'error': error }\">{{value}}</span>\n        <input class=\"form-control\" #propertyInput focusOnInit\n            type=\"text\"\n            *ngIf=\"editing\"\n            [disabled]=\"saving\"\n            [required]=\"required\"\n            (keyup)=\"validate(propertyInput.value)\"\n            (keyup.enter)=\"save(propertyInput.value)\"\n            (keydown.tab)=\"onTab(propertyInput.value, $event)\"\n            (keyup.esc)=\"cancel()\"\n            (blur)=\"cancel()\"\n            [ngClass]=\"{ 'error': error }\"\n            [ngModel]=\"value\"/>\n        <div *ngIf=\"invalid\" class=\"alert alert-danger\">{{ invalidMessage }}</div>\n    "
        }), 
        __metadata('design:paramtypes', [])
    ], ValueHandler);
    return ValueHandler;
}());
exports.ValueHandler = ValueHandler;
var ValueHandler;
(function (ValueHandler) {
    'use strict';
})(ValueHandler = exports.ValueHandler || (exports.ValueHandler = {}));
//# sourceMappingURL=value-handler.js.map