import { AfterContentInit, ElementRef, OnDestroy } from '@angular/core';
import { Subscription } from 'rxjs';
/**
 * This is an attribute directive for dropdown menus, used in combination with the `ueDropdownTrigger` attribute
 * and the `.dropdown-menu` css class.  It can be consumed in your apps and is also used internally in the `filtering`
 * component's template.
 *
 * Simple usage example:
 *
 * ```
 * import { Component } from '@angular/core';
 *
 * @Component({
 *    selector: 'app',
 *    template: `
 *        <div ueDropdown>
 *            <button ueDropdownTrigger>Click to open dropdown</button>
 *            <ul class="dropdown-menu">
 *                <li>Option 1</li>
 *                <li>Option 2</li>
 *                <li>Option 3</li>
 *            </ul>
 *        </div>
 *    `
 * })
 * export class AppComponent {}
 *
 * ```
 *
 *   ** SEE THE DEMO for examples of more advanced usage **
 */
export declare class DropdownDirective implements AfterContentInit, OnDestroy {
    private el;
    private document;
    private readonly classList;
    private documentClickStream;
    documentClickSubscription: Subscription;
    triggerClickSubscription: Subscription;
    contentChildrenSubscription: Subscription;
    private queryList;
    constructor(el: ElementRef, document: any);
    ngAfterContentInit(): void;
    private subscribeToTriggerClickStream(trigger);
    private toggleShow(event, stopPropagation?);
    ngOnDestroy(): void;
}
