"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
var core_1 = require('@angular/core');
var platform_browser_1 = require('@angular/platform-browser');
var rxjs_1 = require('rxjs');
var dropdown_trigger_1 = require('./dropdown-trigger');
/**
 * This is an attribute directive for dropdown menus, used in combination with the `ueDropdownTrigger` attribute
 * and the `.dropdown-menu` css class.  It can be consumed in your apps and is also used internally in the `filtering`
 * component's template.
 *
 * Simple usage example:
 *
 * ```
 * import { Component } from '@angular/core';
 *
 * @Component({
 *    selector: 'app',
 *    template: `
 *        <div ueDropdown>
 *            <button ueDropdownTrigger>Click to open dropdown</button>
 *            <ul class="dropdown-menu">
 *                <li>Option 1</li>
 *                <li>Option 2</li>
 *                <li>Option 3</li>
 *            </ul>
 *        </div>
 *    `
 * })
 * export class AppComponent {}
 *
 * ```
 *
 *   ** SEE THE DEMO for examples of more advanced usage **
 */
var DropdownDirective = (function () {
    function DropdownDirective(el, document) {
        this.el = el;
        this.document = document;
        this.documentClickStream = rxjs_1.Observable.fromEvent(this.document, 'click');
    }
    Object.defineProperty(DropdownDirective.prototype, "classList", {
        get: function () {
            return this.el.nativeElement.classList;
        },
        enumerable: true,
        configurable: true
    });
    DropdownDirective.prototype.ngAfterContentInit = function () {
        var _this = this;
        var first = rxjs_1.Observable.of(this.queryList.first);
        var changes = this.queryList.changes
            .flatMap(function (q) { return rxjs_1.Observable.of(q.first); });
        this.contentChildrenSubscription = rxjs_1.Observable.merge(first, changes)
            .filter(function (d) { return !!d; })
            .subscribe(function (d) { return _this.subscribeToTriggerClickStream(d); });
        this.el.nativeElement.classList.add('dropdown');
    };
    DropdownDirective.prototype.subscribeToTriggerClickStream = function (trigger) {
        var _this = this;
        if (this.triggerClickSubscription) {
            this.triggerClickSubscription.unsubscribe();
        }
        this.triggerClickSubscription = trigger.clickStream.subscribe(function (click) { return _this.toggleShow(click, true); });
    };
    DropdownDirective.prototype.toggleShow = function (event, stopPropagation) {
        var _this = this;
        if (stopPropagation === void 0) { stopPropagation = false; }
        if (stopPropagation) {
            event.stopPropagation();
        }
        this.classList.toggle('open');
        if (this.classList.contains('open')) {
            this.documentClickSubscription = this.documentClickStream.subscribe(function (click) { return _this.toggleShow(click); });
        }
        else {
            this.documentClickSubscription.unsubscribe();
        }
    };
    DropdownDirective.prototype.ngOnDestroy = function () {
        if (this.contentChildrenSubscription) {
            this.contentChildrenSubscription.unsubscribe();
        }
        if (this.triggerClickSubscription) {
            this.triggerClickSubscription.unsubscribe();
        }
        if (this.documentClickSubscription) {
            this.documentClickSubscription.unsubscribe();
        }
    };
    __decorate([
        core_1.ContentChildren(dropdown_trigger_1.DropdownTriggerDirective), 
        __metadata('design:type', core_1.QueryList)
    ], DropdownDirective.prototype, "queryList", void 0);
    DropdownDirective = __decorate([
        core_1.Directive({
            selector: '[ueDropdown]'
        }),
        __param(1, core_1.Inject(platform_browser_1.DOCUMENT)), 
        __metadata('design:paramtypes', [core_1.ElementRef, Object])
    ], DropdownDirective);
    return DropdownDirective;
}());
exports.DropdownDirective = DropdownDirective;
//# sourceMappingURL=dropdown.js.map