import { ElementRef, OnInit } from '@angular/core';
/**
 * This directive is meant to be used for cases where elements must be toggled between visible and hidden on hover events.
 * This will toggle an element's display between none/block.
 *
 * Use the directive identifier in the element that will react to hover events.
 * Use class `show-on-hover` to identify an element that will be shown on hover
 * Use class `hide-on-hover` to identify an element that will be hidden on hover
 *
 * @input You specify if the hide/show behavior is done using inline styles or class toggle: `showToggle = class|style`
 *
 * ### Simple Example
 *
 * ```
 * <div toggleOnHover showToggle="class">
 *      <div class="show-on-hover">This has the class `show-on-hover`</div>
 *      <div class="hide-on-hover">This has the class `hide-on-hover`</div>
 * </div>
 * ```
 */
export declare class ToggleOnHover implements OnInit {
    private el;
    showToggle: string;
    private showOnHover;
    private hideOnHover;
    constructor(el: ElementRef);
    onMouseEnter(): void;
    onMouseLeave(): void;
    private showElement(element);
    private hideElement(element);
    ngOnInit(): void;
}
