"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var core_1 = require('@angular/core');
/**
 * This directive is meant to be used for cases where elements must be toggled between visible and hidden on hover events.
 * This will toggle an element's display between none/block.
 *
 * Use the directive identifier in the element that will react to hover events.
 * Use class `show-on-hover` to identify an element that will be shown on hover
 * Use class `hide-on-hover` to identify an element that will be hidden on hover
 *
 * @input You specify if the hide/show behavior is done using inline styles or class toggle: `showToggle = class|style`
 *
 * ### Simple Example
 *
 * ```
 * <div toggleOnHover showToggle="class">
 *      <div class="show-on-hover">This has the class `show-on-hover`</div>
 *      <div class="hide-on-hover">This has the class `hide-on-hover`</div>
 * </div>
 * ```
 */
var ToggleOnHover = (function () {
    function ToggleOnHover(el) {
        this.el = el;
        this.showToggle = 'style';
    }
    ToggleOnHover.prototype.onMouseEnter = function () {
        this.hideElement('normal');
        this.showElement('hover');
    };
    ToggleOnHover.prototype.onMouseLeave = function () {
        this.hideElement('hover');
        this.showElement('normal');
    };
    ToggleOnHover.prototype.showElement = function (element) {
        var e = element === 'normal' ? this.hideOnHover : this.showOnHover;
        if (e) {
            if (this.showToggle === 'style') {
                e.style.display = 'block';
            }
            else {
                e.classList.remove('hidden');
            }
        }
    };
    ToggleOnHover.prototype.hideElement = function (element) {
        var e = element === 'normal' ? this.hideOnHover : this.showOnHover;
        if (e) {
            if (this.showToggle === 'style') {
                e.style.display = 'none';
            }
            else {
                e.classList.add('hidden');
            }
        }
    };
    ToggleOnHover.prototype.ngOnInit = function () {
        this.showOnHover = this.el.nativeElement.getElementsByClassName('show-on-hover')[0];
        this.hideElement('hover');
        this.hideOnHover = this.el.nativeElement.getElementsByClassName('hide-on-hover')[0];
        this.showElement('normal');
    };
    __decorate([
        core_1.Input(), 
        __metadata('design:type', String)
    ], ToggleOnHover.prototype, "showToggle", void 0);
    __decorate([
        core_1.HostListener('mouseenter'), 
        __metadata('design:type', Function), 
        __metadata('design:paramtypes', []), 
        __metadata('design:returntype', void 0)
    ], ToggleOnHover.prototype, "onMouseEnter", null);
    __decorate([
        core_1.HostListener('mouseleave'), 
        __metadata('design:type', Function), 
        __metadata('design:paramtypes', []), 
        __metadata('design:returntype', void 0)
    ], ToggleOnHover.prototype, "onMouseLeave", null);
    ToggleOnHover = __decorate([
        core_1.Directive({
            selector: '[toggleOnHover]'
        }), 
        __metadata('design:paramtypes', [core_1.ElementRef])
    ], ToggleOnHover);
    return ToggleOnHover;
}());
exports.ToggleOnHover = ToggleOnHover;
//# sourceMappingURL=toggle-on-hover.js.map