"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var core_1 = require('@angular/core');
var rxjs_1 = require('rxjs');
/**
 * This is a simple service that allows any tooltip attribute directives that you use in your application to communicate
 * with the tooltip component in your root component template.
 *
 * Simple tooltip usage example:
 *
 * 1) Include TooltipService in the `providers` section of ngModule, in app.module.ts for example:
 * ```
 *  @NgModule({
 *     bootstrap:    [ AppComponent ],
 *     declarations: [
 *         AppsMain,
 *         ContextBar,
 *         Row
 *     ],
 *     imports:      [
 *         BrowserModule,
 *         HttpModule,
 *         Ng2UEUtilsModule,
 *         RouterModule.forRoot(appLocalRoutes)
 *     ],
 *     providers: [
 *         AppClient,
 *         AppRepository,
 *         NotificationService,
 *         TooltipService, // ** HERE **
 *         ProgressService,
 *         Location,
 *         WindowRef,
 *         { provide: APP_CONFIG, useValue: appConfig }
 *     ]
 * })
 *  export class AppModule {}
 * ```
 *
 * 2) Add the tooltip component to your root component's template, eg: app.component.ts:
 *
 * ```
 * import { Component } from '@angular/core';
 *
 * @Component({
 *    selector: 'app',
 *    template: `
 *        <router-outlet></router-outlet>
 *        <ue-tooltip></ue-tooltip>
 *    `
 * })
 * export class AppComponent {}
 *
 * ```
 *
 * **Important** The tooltip component should be included in your root component template and not any lower.  It relies
 * on this placement to properly position itself around the page.
 *
 *
 * 3) Finally, use the directive somewhere in your app:
 *
 *  * ```
 * import { Component } from '@angular/core';
 *
 * @Component({
 *    selector: 'app',
 *    template: `
 *        <div ueTooltip="This is a div"></div>
 *    `
 * })
 * export class AppComponent {}
 *
 * ```
 *
 *   ** SEE THE DEMO for examples of more advanced usage **
 */
var TooltipService = (function () {
    function TooltipService() {
        this.observer = new rxjs_1.BehaviorSubject(undefined);
        this.tooltipOptions = this.observer.asObservable();
    }
    TooltipService.prototype.notify = function (options) {
        this.observer.next(options);
    };
    TooltipService = __decorate([
        core_1.Injectable(), 
        __metadata('design:paramtypes', [])
    ], TooltipService);
    return TooltipService;
}());
exports.TooltipService = TooltipService;
//# sourceMappingURL=tooltip-service.js.map