"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var core_1 = require('@angular/core');
var tooltip_service_1 = require('./tooltip-service');
/**
 * This attribute directive is your interface for positioning and controlling the state of the tooltip component
 * included in this library.  See the below for usage instructions.
 *
 * @input tooltip: string
 *  This is the content of your tooltip
 *
 * @input tooltipEnabled: boolean
 *  This determines whether your tooltip will be displayed or not.  When it is dynamically set to true, it will fade in.
 *  When it is dynamically set to false, it will immediately disappear.
 *
 * @input tooltipPlacement: TooltipPlacement = 'top' | 'bottom' | 'left' | 'right'
 *  This determines on which side of the host element your tooltip will appear.  **BUG** When dynamically changing this
 *  value there may be positioning inaccuracies until the user mouses out and back into the host element, especially in Safari.
 *
 * @input maxWidth: number
 *  This determines the maximum width of the content.  **BUG** When dynamically changing this value there may be
 *  positioning inaccuracies until the user mouses out and back into the host element, especially in Safari.
 *
 *  **USAGE**:
 *
 * 1) Include TooltipService in the `providers` section of ngModule, in app.module.ts for example:
 *
 * ```
 *  @NgModule({
 *     bootstrap:    [ AppComponent ],
 *     declarations: [
 *         AppsMain,
 *         ContextBar,
 *         Row
 *     ],
 *     imports:      [
 *         BrowserModule,
 *         HttpModule,
 *         Ng2UEUtilsModule,
 *         RouterModule.forRoot(appLocalRoutes)
 *     ],
 *     providers: [
 *         AppClient,
 *         AppRepository,
 *         NotificationService,
 *         TooltipService, // ** HERE **
 *         ProgressService,
 *         Location,
 *         WindowRef,
 *         { provide: APP_CONFIG, useValue: appConfig }
 *     ]
 * })
 *  export class AppModule {}
 * ```
 *
 * 2) Add the tooltip component to your root component's template, eg: app.component.ts:
 *
 * ```
 * import { Component } from '@angular/core';
 *
 * @Component({
 *    selector: 'app',
 *    template: `
 *        <router-outlet></router-outlet>
 *        <ue-tooltip></ue-tooltip>
 *    `
 * })
 * export class AppComponent {}
 *
 * ```
 *
 * **Important** The tooltip component should be included in your root component template and not any lower.  It relies
 * on this placement to properly position itself around the page.
 *
 *
 * 3) Finally, use the directive somewhere in your app:
 *
 *  * ```
 * import { Component } from '@angular/core';
 *
 * @Component({
 *    selector: 'app',
 *    template: `
 *        <div ueTooltip="This is a div"></div>
 *    `
 * })
 * export class AppComponent {}
 *
 * ```
 *
 *   ** SEE THE DEMO for examples of more advanced usage **
 */
var TooltipDirective = (function () {
    function TooltipDirective(service) {
        this.service = service;
        this.hovering = false;
        this.maxWidth = 200;
        this.content = '';
        this.enabled = true;
        this.placement = 'top';
        this.target = undefined;
    }
    TooltipDirective.prototype.onMouseEnter = function (event) {
        this.target = event.target;
        this.hovering = true;
        this.notifyTooltipComponent();
    };
    TooltipDirective.prototype.onMouseLeave = function () {
        this.hovering = false;
        this.notifyTooltipComponent();
    };
    TooltipDirective.prototype.notifyTooltipComponent = function () {
        var options = {
            content: this.content,
            enabled: this.enabled,
            hovering: this.hovering,
            maxWidth: this.maxWidth,
            placement: this.placement,
            target: this.target
        };
        this.service.notify(options);
    };
    TooltipDirective.prototype.ngOnChanges = function () {
        this.notifyTooltipComponent();
    };
    TooltipDirective.prototype.ngOnDestroy = function () {
        this.target = undefined;
        this.hovering = false;
        this.notifyTooltipComponent();
    };
    __decorate([
        core_1.Input('ueTooltipMaxWidth'), 
        __metadata('design:type', Number)
    ], TooltipDirective.prototype, "maxWidth", void 0);
    __decorate([
        core_1.Input('ueTooltip'), 
        __metadata('design:type', String)
    ], TooltipDirective.prototype, "content", void 0);
    __decorate([
        core_1.Input('ueTooltipEnabled'), 
        __metadata('design:type', Boolean)
    ], TooltipDirective.prototype, "enabled", void 0);
    __decorate([
        core_1.Input('ueTooltipPlacement'), 
        __metadata('design:type', String)
    ], TooltipDirective.prototype, "placement", void 0);
    __decorate([
        core_1.HostListener('mouseenter', ['$event']), 
        __metadata('design:type', Function), 
        __metadata('design:paramtypes', [MouseEvent]), 
        __metadata('design:returntype', void 0)
    ], TooltipDirective.prototype, "onMouseEnter", null);
    __decorate([
        core_1.HostListener('mouseleave'), 
        __metadata('design:type', Function), 
        __metadata('design:paramtypes', []), 
        __metadata('design:returntype', void 0)
    ], TooltipDirective.prototype, "onMouseLeave", null);
    TooltipDirective = __decorate([
        core_1.Directive({
            selector: '[ueTooltip]'
        }), 
        __metadata('design:paramtypes', [tooltip_service_1.TooltipService])
    ], TooltipDirective);
    return TooltipDirective;
}());
exports.TooltipDirective = TooltipDirective;
//# sourceMappingURL=tooltip.js.map