"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var core_1 = require('@angular/core');
var http_1 = require('@angular/http');
var Rx_1 = require('rxjs/Rx');
var client_request_options_1 = require('./client-request-options');
var window_ref_1 = require('../window-ref');
var knownCodes = [401, 403];
var defaultErrorMessages = {
    '401': 'Unauthorized',
    '403': 'Forbidden. You don\'t have permissions to access this resource.'
};
var extractSimplifiedError = function (error, path) {
    if (!error) {
        return {
            code: 'Unknown Error',
            message: 'Unknown error processing path: ' + path,
            originalError: error,
            path: path
        };
    }
    try {
        var err = error.json();
        return {
            code: err.code,
            message: err.message,
            originalError: error,
            path: path,
        };
    }
    catch (e) {
        return {
            code: error.status || 'Unknown Error',
            message: defaultErrorMessages[error.status.toString()] || 'Unknown error processing path: ' + path,
            originalError: error,
            path: path
        };
    }
};
var mapToJson = function (obs) {
    return obs.map(function (response) {
        return ((response && response.text()) ? response.json() : undefined);
    });
};
var errorOrRedirect = function (path, error, win) {
    if (error && error.status === 401 && error.headers && error.headers.get) {
        var errorLocation = error.headers.get('location') || error.headers.get('Location');
        console.log('[SPA] Unauthorized call detected. Trying redirection to:', errorLocation);
        win.location(errorLocation);
    }
    return Rx_1.Observable.throw(extractSimplifiedError(error, path));
};
var Client = (function () {
    function Client(http, win) {
        var _this = this;
        this.http = http;
        this.win = win;
        this.catchOrRedirect = function (path) {
            return function (error, caught) { return errorOrRedirect(path, error, _this.win); };
        };
        this.mapAndCatch = function (path, obs) { return mapToJson(obs
            .flatMap(function (resp) {
            if (knownCodes.indexOf(resp.status) >= 0) {
                return Rx_1.Observable.throw(resp);
            }
            return Rx_1.Observable.of(resp);
        })
            .catch(_this.catchOrRedirect(path))); };
        this.get = function (path, options) {
            // TODO: Fix for breaking change in Angular 2 RC5: http get requests need to have a non empty body
            // https://github.com/angular/angular/issues/10612 Should be fixed in RC6
            if (!options) {
                options = {};
            }
            if (!options.body) {
                options.body = '';
            }
            return _this.mapAndCatch(path, _this.http.get(path, new client_request_options_1.ClientRequestOptions(options)));
        };
        this.delete = function (path, options) {
            return _this.mapAndCatch(path, _this.http.delete(path, new client_request_options_1.ClientRequestOptions(options)));
        };
        this.put = function (path, payload, options) {
            return _this.mapAndCatch(path, _this.http.put(path, JSON.stringify(payload), new client_request_options_1.ClientRequestOptions(options)));
        };
        this.post = function (path, payload, options) {
            return _this.mapAndCatch(path, _this.http.post(path, JSON.stringify(payload), new client_request_options_1.ClientRequestOptions(options)));
        };
    }
    Client = __decorate([
        core_1.Injectable(), 
        __metadata('design:paramtypes', [http_1.Http, window_ref_1.WindowRef])
    ], Client);
    return Client;
}());
exports.Client = Client;
//# sourceMappingURL=client.js.map