import { RequestOptionsArgs } from '@angular/http';
import { Observable } from 'rxjs/Rx';
import { IClientBase } from './client';
/**
 * This injectable service can be used on your tests to mock asynchronous http calls.
 *
 * ### Simple Example
 *
 * Add service to your test file before each test is run and get the client mock instance
 *
 * ```
 * let myCustomClient: MyCustomClient;
 * let client: ClientMock;
 * beforeEach(() => {
 *       TestBed.configureTestingModule({
 *           imports: [ Ng2UEUtilsModule ],
 *           providers:      [
 *               MyCustomClient,
 *               ClientObserver,
 *               { provide: Client, useClass: ClientMock },
 *               { provide: APP_CONFIG, useValue: appConfig }
 *           ]
 *       });
 *       myCustomClient = TestBed.get(MyCustomClient);
 *       client = TestBed.get(Client);
 *   });
 * ```
 *
 * And in each of your tests
 * ```
 * it('Gets entity list', (done) => {
 *      const mockResponse = { id: 123, name: 'mockName' };
 *      client.on(`/my/entity/relative/route?myQueryParam=100`, mockResponse); // route configured on your router for getMyEntityList
 *      let counter = 0;
 *
 *      myCustomClient.getMyEntitiesList().subscribe(
 *           () => {
 *              // Add your test code for each next event
 *               counter += 1;
 *               switch (counter) {
 *                    case 1:
 *                       // your test for first emission
 *                       break;
 *                   case 2:
 *                       // your test for second emission, and so on,
 *                       break;
 *                   default:
 *                       expect('Should not enter default case').toBeUndefined();
 *                       done();
 *                       break;
 *               }
 *           },
 *           () => {
 *           // add your test code for each error event
 *               expect('Should not enter here').toBeUndefined();
 *               done();
 *           },
 *           () => {
 *           // add your test code for complete event
 *               expect(counter).toBe(0);
 *               done();
 *           }
 *       );
 *   });
 *
 * ```
 */
export declare class ClientMock implements IClientBase {
    private predefinedResponses;
    constructor();
    private request;
    on: <T>(path: string, value: any, error?: boolean) => void;
    get: <T>(path: string, options?: RequestOptionsArgs) => Observable<T>;
    put: <T, U>(path: string, payload: U, options?: RequestOptionsArgs) => Observable<T>;
    post: <T, U>(path: string, payload: U, options?: RequestOptionsArgs) => Observable<T>;
    delete: <T>(path: string, options?: RequestOptionsArgs) => Observable<T>;
}
