"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var core_1 = require('@angular/core');
var Rx_1 = require('rxjs/Rx');
/**
 * This injectable service can be used on your tests to mock asynchronous http calls.
 *
 * ### Simple Example
 *
 * Add service to your test file before each test is run and get the client mock instance
 *
 * ```
 * let myCustomClient: MyCustomClient;
 * let client: ClientMock;
 * beforeEach(() => {
 *       TestBed.configureTestingModule({
 *           imports: [ Ng2UEUtilsModule ],
 *           providers:      [
 *               MyCustomClient,
 *               ClientObserver,
 *               { provide: Client, useClass: ClientMock },
 *               { provide: APP_CONFIG, useValue: appConfig }
 *           ]
 *       });
 *       myCustomClient = TestBed.get(MyCustomClient);
 *       client = TestBed.get(Client);
 *   });
 * ```
 *
 * And in each of your tests
 * ```
 * it('Gets entity list', (done) => {
 *      const mockResponse = { id: 123, name: 'mockName' };
 *      client.on(`/my/entity/relative/route?myQueryParam=100`, mockResponse); // route configured on your router for getMyEntityList
 *      let counter = 0;
 *
 *      myCustomClient.getMyEntitiesList().subscribe(
 *           () => {
 *              // Add your test code for each next event
 *               counter += 1;
 *               switch (counter) {
 *                    case 1:
 *                       // your test for first emission
 *                       break;
 *                   case 2:
 *                       // your test for second emission, and so on,
 *                       break;
 *                   default:
 *                       expect('Should not enter default case').toBeUndefined();
 *                       done();
 *                       break;
 *               }
 *           },
 *           () => {
 *           // add your test code for each error event
 *               expect('Should not enter here').toBeUndefined();
 *               done();
 *           },
 *           () => {
 *           // add your test code for complete event
 *               expect(counter).toBe(0);
 *               done();
 *           }
 *       );
 *   });
 *
 * ```
 */
var ClientMock = (function () {
    function ClientMock() {
        var _this = this;
        this.request = function (path) {
            return new Rx_1.Observable(function (observer) {
                if (_this.predefinedResponses[path]) {
                    if (_this.predefinedResponses[path].error) {
                        observer.error(_this.predefinedResponses[path].value);
                    }
                    else {
                        observer.next(_this.predefinedResponses[path].value);
                    }
                    observer.complete();
                }
                else {
                    observer.error({ message: 'No handler for path: ' + path });
                }
            }).delay(0);
        };
        this.on = function (path, value, error) {
            _this.predefinedResponses[path] = { error: error, value: value };
        };
        this.get = function (path, options) {
            return _this.request(path);
        };
        this.put = function (path, payload, options) {
            return _this.request(path);
        };
        this.post = function (path, payload, options) {
            return _this.request(path);
        };
        this.delete = function (path, options) {
            return _this.request(path);
        };
        this.predefinedResponses = {
            '/userinfo': {
                value: {
                    'user_id': '1c95f365',
                    'user_name': 'dimitri@apigee.com',
                    'given_name': 'Dmitri',
                    'family_name': 'Karamazov',
                    'email': 'dimitri@apigee.com',
                    'name': 'Dimitri Fyodorovich Karamazov'
                }
            },
            '/users/dimitri@apigee.com/userroles': {
                value: {
                    role: [{ name: 'orgadmin', organization: 'abc' }]
                }
            },
            '/organizations/abc/userroles/orgadmin/permissions': {
                value: {
                    resourcePermission: [{ organization: 'abc', path: '/', permissions: ['get', 'put', 'delete'] }]
                }
            }
        };
    }
    ClientMock = __decorate([
        core_1.Injectable(), 
        __metadata('design:paramtypes', [])
    ], ClientMock);
    return ClientMock;
}());
exports.ClientMock = ClientMock;
//# sourceMappingURL=client.mock.js.map