"use strict";
var jwt_1 = require('./jwt');
var Cookie = (function () {
    function Cookie(key, value) {
        this.key = key;
        this.value = value;
    }
    return Cookie;
}());
exports.Cookie = Cookie;
var ContextHelper = (function () {
    function ContextHelper(window, gtmAppName) {
        var _this = this;
        this.window = window;
        this.gtmAppName = gtmAppName;
        this.accessToken = function () { return _this.cookie('access_token'); };
        this.jwt = function () { return new jwt_1.Jwt(_this.accessToken()); };
        this.getUser = function () { return _this.jwt().user; };
        this.getUuid = function () { return _this.jwt().uuid; };
    }
    ContextHelper.prototype.orgNameFromPath = function (path) {
        var parts = /^\/(?:o|organizations)\/([^\/]+)\//.exec(path);
        if (parts && parts.length > 1) {
            return parts[1];
        }
    };
    ContextHelper.prototype.orgNameFromLocal = function () {
        var name = this.window.getLocal('organization');
        // Ensure it is undefined instead of null.
        if (!name && name !== undefined) {
            name = undefined;
        }
        return name;
    };
    ContextHelper.prototype.orgNameToLocal = function (name) {
        this.window.setLocal('organization', name);
    };
    ContextHelper.prototype.updateGtmContext = function (orgName, uuid, email) {
        var context = {
            'organization.name': orgName,
            'webapp.name': this.gtmAppName,
            'event': 'Push Context'
        };
        if (/^[^@]+@apigee.com/.test(email || '')) {
            context['user.internal'] = 'internal';
        }
        if (uuid) {
            context['user.uuid'] = uuid;
        }
        if (email) {
            context['user.email'] = email;
        }
        this.window.gtmContext(context);
    };
    ContextHelper.prototype.cookies = function () {
        var docCookie = this.window.cookies();
        if (docCookie) {
            return docCookie.split(';').map(function (c) {
                var pair = c.split('=');
                if (pair.length >= 2) {
                    return { key: pair[0].trim(), value: pair[1].trim() };
                }
                return { key: c, value: c };
            });
        }
        return [];
    };
    ContextHelper.prototype.cookie = function (key) {
        var c = this.cookies().find(function (cc) { return cc.key === key; });
        if (c) {
            return c.value;
        }
    };
    return ContextHelper;
}());
exports.ContextHelper = ContextHelper;
//# sourceMappingURL=context-helper.js.map