"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
var core_1 = require('@angular/core');
var common_1 = require('@angular/common');
require('rxjs/Rx');
var context_helper_1 = require('./context-helper');
var window_ref_1 = require('../window-ref');
exports.APP_CONFIG = new core_1.OpaqueToken('AppConfig');
var Context = (function () {
    function Context(_orgName) {
        this._orgName = _orgName;
    }
    Object.defineProperty(Context.prototype, "orgName", {
        get: function () { return this._orgName; },
        enumerable: true,
        configurable: true
    });
    return Context;
}());
exports.Context = Context;
var EmptyContext = (function () {
    function EmptyContext() {
    }
    Object.defineProperty(EmptyContext.prototype, "orgName", {
        get: function () { return undefined; },
        enumerable: true,
        configurable: true
    });
    return EmptyContext;
}());
/**
 * This service is used to get the organization and user context in which an SPA is being used.
 * Ideally, it should be included as part of your providers in your app.component file so all the application has access to it.
 * Its dependencies must be provided in app.component as well.
 * So, your app.component.ts should look something like this
 *
 * ```
 * import { Location } from '@angular/common';
 * import { Component } from '@angular/core';
 * import { HTTP_PROVIDERS } from '@angular/http';
 * import { APP_CONFIG, ContextService, Client, IAppConfig, WindowRef } from 'ng2-ue-utils';
 *
 * import { MyMainComponent } from './route/to/myMainComponent';
 *
 * const appConfig: IAppConfig = {
 *   apiBasePath: 'myapibasepath',
 *   appBasePath: 'myappbasepath',
 *   gtmAppName: 'nameforgoogletagmanager'
 * };
 *
 * @Component({
 *   directives: [
 *       MyMainComponent
 *   ],
 *   providers: [
 *       HTTP_PROVIDERS,
 *       Location,
 *       Client,
 *       ContextService,
 *       WindowRef,
 *       { provide: APP_CONFIG, useValue: appConfig }
 *   ],
 *   selector: 'app',
 *   template: '<myMainComponent-or-routerOutlet></myMainComponent-or-routerOutlet>'
 * })
 * export class AppComponent {}
 * ```
 *
 * The most common usage for it is to get the organization name inside a component.
 * To do that inject it in the component constructor and do
 *
 * ```
 * const org: string = this.context.orgName;
 * ```
 *
 */
var ContextService = (function () {
    function ContextService(location, window, appConfig) {
        this.location = location;
        this.window = window;
        this.appConfig = appConfig;
        this.helper = new context_helper_1.ContextHelper(window, this.appConfig.gtmAppName);
    }
    ContextService.prototype.getContext = function () {
        // get org from location
        var path = this.location.path();
        var orgFromUrl = this.helper.orgNameFromPath(path);
        var userName = this.helper.getUser();
        var userId = this.helper.getUuid();
        if (orgFromUrl) {
            // Ensure Local Storage is in sync with current selection
            this.helper.orgNameToLocal(orgFromUrl);
            this.helper.updateGtmContext(orgFromUrl, userId, userName);
            return new Context(orgFromUrl);
        }
        // If no org is the URL, try to get it from Local Storage
        var orgFromLocalStorage = this.helper.orgNameFromLocal();
        if (orgFromLocalStorage) {
            // Redirect to the org:
            var newPath = "/organizations/" + orgFromLocalStorage + "/" + this.appConfig.appBasePath;
            this.helper.updateGtmContext(orgFromLocalStorage, userId, userName);
            this.location.go(newPath);
            return new Context(orgFromLocalStorage);
        }
        // If no org in Local Storage, redirecto to no-org page (alm-static)
        this.window.location('/no-org');
        return new EmptyContext();
    };
    Object.defineProperty(ContextService.prototype, "orgName", {
        get: function () {
            if (this._orgName) {
                return this._orgName;
            }
            this._orgName = this.getContext().orgName;
            return this._orgName;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ContextService.prototype, "userEmail", {
        get: function () {
            return this.helper.getUser();
        },
        enumerable: true,
        configurable: true
    });
    ContextService = __decorate([
        core_1.Injectable(),
        __param(2, core_1.Inject(exports.APP_CONFIG)), 
        __metadata('design:paramtypes', [common_1.Location, window_ref_1.WindowRef, Object])
    ], ContextService);
    return ContextService;
}());
exports.ContextService = ContextService;
//# sourceMappingURL=context.js.map