import { RolePermissions } from 'rbac-abacus';
import { PartialObserver } from 'rxjs/Observer';
import { Observable } from 'rxjs/Rx';
import { Subscription } from 'rxjs/Subscription';
import { ObservableClient } from '../client/observable-client';
import { SetOrder } from './base-storage';
import { Storage } from './storage';
export declare type RepositoryStatus = 'empty' | 'loading' | 'loaded' | 'error';
export interface IRangeSnapshot<T> {
    count: number;
    error?: any;
    filteredCount: number;
    from: number;
    to: number;
    range: T[];
    allowRead?: boolean;
    allowCreate?: boolean;
}
export declare abstract class Repository<T> extends Observable<IRangeSnapshot<T>> {
    protected client: ObservableClient;
    basePath: string;
    storage: Storage<T>;
    private end;
    private latest;
    private observers;
    private start;
    private _status;
    protected _permissions: RolePermissions;
    protected abstract buildEntity(raw: any, permissions?: RolePermissions): T;
    constructor(client: ObservableClient, basePath: string, storage: Storage<T>);
    private loadFromClient;
    protected doNext: (error?: any) => void;
    protected doError: (error: any) => void;
    private doEmit;
    private load;
    private permissions;
    readonly status: RepositoryStatus;
    readonly filteredCount: number;
    readonly collectionCount: number;
    readonly filterString: string;
    readonly filterField: string;
    readonly sortByOrder: SetOrder;
    readonly sortByField: string;
    filterBy: (pattern?: string, field?: string) => void;
    sortBy: (field: string, order: "desc" | "asc") => void;
    delete: (identifier: string) => Observable<T>;
    create: (rawEntity: any) => void;
    setRange: (start: number, end: number) => void;
    subscribe(observerOrNext?: PartialObserver<IRangeSnapshot<T>> | ((value: IRangeSnapshot<T>) => void), error?: (error: any) => void, complete?: () => void): Subscription;
}
