"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var _ = require('lodash');
var Rx_1 = require('rxjs/Rx');
var Repository = (function (_super) {
    __extends(Repository, _super);
    function Repository(client, basePath, storage) {
        var _this = this;
        _super.call(this, function (obs) {
            _this.observers.push(obs);
            return function () {
                _.remove(_this.observers, obs);
            };
        });
        this.client = client;
        this.basePath = basePath;
        this.storage = storage;
        this.loadFromClient = function () {
            _this.client.getList()
                .subscribe(function (rawEntities) {
                if (_this.start < 0 && rawEntities.length > 0) {
                    _this.start = 0;
                    _this.end = 25;
                }
                var entities = rawEntities.map(function (r) {
                    return _this.buildEntity(r, _this._permissions);
                });
                _this.storage.bulkAppend(entities);
                _this.doNext();
            }, function (error) {
                _this._status = 'error';
                _this.doNext(error);
            }, function () {
                _this._status = 'loaded';
                _this.doNext();
            });
        };
        this.doNext = function (error) {
            if (error) {
                _this.doError(error);
                return;
            }
            _this.permissions().subscribe(function (permissions) {
                var range = _this.storage.range(_this.start, _this.end);
                var ops = permissions ? permissions.allowsOperations("/" + _this.basePath) : [];
                _this.latest = {
                    allowCreate: ops.indexOf('put') >= 0,
                    allowRead: ops.indexOf('get') >= 0,
                    count: _this.collectionCount,
                    filteredCount: _this.filteredCount,
                    from: _this.start,
                    range: range,
                    to: Math.max(_this.start + range.length, 0)
                };
                _this.doEmit();
            }, function (err) { return _this.doError(err); });
        };
        this.doError = function (error) {
            var latest = {
                allowCreate: undefined,
                allowRead: undefined,
                count: _this.latest.count,
                error: error,
                filteredCount: _this.latest.filteredCount,
                from: _this.latest.from,
                range: _this.latest.range,
                to: _this.latest.to
            };
            _this.permissions().subscribe(function (permissions) {
                var ops = permissions ? permissions.allowsOperations("/" + _this.basePath) : [];
                latest.allowCreate = ops.indexOf('put') >= 0;
                latest.allowRead = ops.indexOf('get') >= 0;
                _this.latest = latest;
            }, function (err) { return _this.latest = latest; }, function () {
                _this.doEmit();
            });
        };
        this.doEmit = function () {
            _this.observers.forEach(function (obs) {
                obs.next(_this.latest);
            });
        };
        this.load = function () {
            if (_this._status !== 'empty') {
                return;
            }
            _this._status = 'loading';
            _this.permissions().subscribe(function (permissions) {
                _this.loadFromClient();
            }, function (error) {
                _this._status = 'error';
                _this.doNext(error);
            });
        };
        this.permissions = function () {
            if (!_this._permissions) {
                return _this.client.permissions().do(function (permissions) { _this._permissions = permissions; });
            }
            return Rx_1.Observable.of(_this._permissions);
        };
        this.filterBy = function (pattern, field) {
            if (_this.filterString === pattern && _this.filterField === (field || '*')) {
                return;
            }
            _this.storage.filterBy(pattern, field);
            _this.doNext();
        };
        this.sortBy = function (field, order) {
            if (_this.sortByField === field && _this.sortByOrder === order) {
                return;
            }
            _this.storage.sortBy(field, order);
            _this.doNext();
        };
        this.delete = function (identifier) {
            var s = new Rx_1.Subject();
            var encodedName = encodeURIComponent(identifier);
            _this.client.deleteEntity(encodedName).subscribe(function (e) {
                s.next(_this.buildEntity(e, _this._permissions));
                _this.storage.remove(identifier);
            }, function (error) {
                s.error(error);
                _this.doNext(error);
            }, function () {
                s.complete();
                _this.doNext();
            });
            return s;
        };
        this.create = function (rawEntity) {
            _this.client.createEntity(rawEntity)
                .subscribe(function (e) {
                _this.storage.append(_this.buildEntity(e, _this._permissions));
            }, function (error) {
                _this.doNext(error);
            }, function () {
                _this.doNext();
            });
        };
        this.setRange = function (start, end) {
            if (start < 0) {
                start = 0;
            }
            if (end < 0) {
                end = 0;
            }
            _this.start = start;
            _this.end = end;
            _this.doNext();
        };
        this.observers = [];
        this.start = -1;
        this.end = 0;
        this.latest = {
            count: 0,
            filteredCount: 0,
            from: -1,
            range: [],
            to: 0
        };
        this._status = 'empty';
    }
    Object.defineProperty(Repository.prototype, "status", {
        get: function () {
            return this._status;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Repository.prototype, "filteredCount", {
        get: function () {
            return this.storage.filteredCount;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Repository.prototype, "collectionCount", {
        get: function () {
            return this.storage.count;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Repository.prototype, "filterString", {
        get: function () {
            return this.storage.filter;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Repository.prototype, "filterField", {
        get: function () {
            return this.storage.filterByField;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Repository.prototype, "sortByOrder", {
        get: function () {
            return this.storage.sortByOrder;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Repository.prototype, "sortByField", {
        get: function () {
            return this.storage.sortByField;
        },
        enumerable: true,
        configurable: true
    });
    Repository.prototype.subscribe = function (observerOrNext, error, complete) {
        var s = _super.prototype.subscribe.call(this, observerOrNext, error, complete);
        this.load();
        return s;
    };
    ;
    return Repository;
}(Rx_1.Observable));
exports.Repository = Repository;
//# sourceMappingURL=repository.js.map