"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var _ = require('lodash');
var base_storage_1 = require('./base-storage');
// `Dictionary<T>` tells the lodash method `_.some()` which kind of collection to expect, in this case an object, which 
// is described by the lodash interface `Dictionary`
exports.createDictionaryFilter = function (pattern, field) {
    var fieldName = field === '*' ? undefined : field;
    if (!pattern && !fieldName) {
        return function (d) { return true; };
    }
    if (!fieldName) {
        return function (d) {
            return _.some(d, function (prop) {
                return _.isUndefined(prop) ? false : prop.toString().toLowerCase().indexOf(pattern.toLocaleLowerCase()) >= 0;
            });
        };
    }
    return function (d) {
        var v = _.get(d, fieldName);
        return v ? v.toString().toLowerCase().indexOf(pattern.toLocaleLowerCase()) >= 0 : false;
    };
};
var Storage = (function (_super) {
    __extends(Storage, _super);
    function Storage() {
        _super.call(this);
        this.entities = {};
        this.filtered = [];
        this.ordered = [];
        this._sortByOrder = 'asc';
    }
    Object.defineProperty(Storage.prototype, "count", {
        get: function () {
            return _.keys(this.entities).length;
        },
        enumerable: true,
        configurable: true
    });
    Storage.prototype.filterAndSort = function () {
        var _this = this;
        var filter = exports.createDictionaryFilter(this.filter, this.filterByField);
        this.filtered = this.filter ?
            _.filter(this.entities, function (p) { return _this.matchType(filter, p); }) :
            _.values(this.entities);
        this.sort();
    };
    ;
    Storage.prototype.remove = function (identifier) {
        delete this.entities[identifier];
        this.filterAndSort();
    };
    ;
    Storage.prototype.append = function (entity) {
        this.entities[this.getId(entity)] = entity;
        this.filterAndSort();
    };
    ;
    Storage.prototype.bulkAppend = function (list) {
        var _this = this;
        list.forEach(function (e) {
            _this.entities[_this.getId(e)] = e;
        });
        this.filterAndSort();
    };
    ;
    return Storage;
}(base_storage_1.BaseStorage));
exports.Storage = Storage;
//# sourceMappingURL=storage.js.map